@@ -11,7 +11,10 @@ from sqlite3 import Error
 from oauthlib.oauth1.rfc5849 import signature, parameters
 import pandas as pd
 import pytz
-from jupyterhub.services.auth import HubAuthenticated
+
+from jupyterhub.services.auth import HubOAuthCallbackHandler
+from jupyterhub.services.auth import HubOAuthenticated
+from jupyterhub.utils import url_path_join
 from lxml import etree
 import aiohttp
 import async_timeout
@@ -213,23 +216,23 @@ async def post_grade(user_id, grade, course, section, assignment):
         raise Exception(f"Problem Posting Grade to LTI:{ex}") from ex
 
 
-class GoferHandler(HubAuthenticated, tornado.web.RequestHandler):
+class GoferHandler(HubOAuthenticated, tornado.web.RequestHandler):
     """
     This class handles the HTTP requests for this tornado instance
     """
-    async def data_received(self, chunk):
+    def data_received(self, chunk):
         """
         abstract methods empty
         :param chunk
         """
         self.write("This is a post only page. You probably shouldn't be here!")
 
-    async def get(self):
+    def get(self):
         self.write("This is a post only page. You probably shouldn't be here!")
         self.finish()
 
     @authenticated
-    async def post(self):
+    def post(self):
         notebook = None
         section = None
         assignment = None
@@ -394,8 +397,17 @@ def start_server():
     """
     tornado.options.parse_command_line()
 
-    app = tornado.web.Application([(PREFIX, GoferHandler)],
-                                  cookie_secret=os.urandom(32))
+    app = tornado.web.Application(
+        [
+            (PREFIX, GoferHandler),
+            (
+                url_path_join(
+                    os.environ['JUPYTERHUB_SERVICE_PREFIX'], 'oauth_callback'
+                ),
+                HubOAuthCallbackHandler,
+            )
+        ],
+        cookie_secret=os.urandom(32))
 
     logger = logging.getLogger('tornado.application')
     file_handler = logging.FileHandler(SERVER_LOG_FILE)
